hepconvert.root_to_parquet
==========================

Defined in `hepconvert.root_to_parquet <https://github.com/zbilodea/hepconvert/blob/52e6cbfbbf81c669ca31b8a538d8f3e8984b35a5/src/hepconvert/root_to_parquet.py>`__ on `line 9 <https://github.com/zbilodea/hepconvert/blob/52e6cbfbbf81c669ca31b8a538d8f3e8984b35a5/src/hepconvert/root_to_parquet.py#L9>`__.

.. autofunction:: hepconvert.root_to_parquet
